package de.hawhamburg.reachability.properties.json;

import java.util.Map;

import de.hawhamburg.lifecycle.data.JsonLPObject;
import de.hawhamburg.reachability.conf.enumeration.ConfigType;
import de.hawhamburg.reachability.properties.PropertyDescription;

/**
 * Properties result JSON message object.<br><br>
 * 
 * This class represents the structure of the json messages which describes the result of a properties request related 
 * to this reachability agent. This messages will provide the the current values of the requested properties as string 
 * and a description of these properties for the purpose of visualization and change management.
 * 
 * @author  {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_AUTHOR} 
 * @version {@value de.hawhamburg.reachability.ProjectInfo#REACHABILITY_AGENT_VERSION}
 */
public class JsonRAPropertiesResult extends JsonLPObject {
    
    /**
     * The ID of the properties request on which this message will be the response. 
     */
    public String RequestId;
    
    /**
     * The general type of properties (e.g. SYSTEM or REASONER). 
     */
    public ConfigType Type;
    
    /**
     * The service state reference (entitles for change).
     */
    public String ServiceStateReference;
    
    /**
     * The requested properties an their values as {@link Map} of {@link String} to {@link String}.
     */
    public Map<String, String> Properties;
    
    /**
     * The description of the requested properties as {@link Map} of {@link String} to {@link PropertyDescription}.
     */
    public Map<String, PropertyDescription> PropertiesDescription;
    
    /**
     * Public default constructor to create instances of this class.
     */
    public JsonRAPropertiesResult() { }
    
}
